require 'puppetx'
require 'puppet/ssl/validator'
require 'puppet/ssl/validator/default_validator'

module Puppetx::Puppetlabs::PEConsole
  module SSL
    module Validator

      class CertnameValidator < Puppet::SSL::Validator::DefaultValidator

        # Creates a new DefaultValidator, optionally with an SSL Configuration and SSL Host.
        #
        # @param [Puppet::SSL::Configuration] (a default configuration) ssl_configuration the SSL configuration to use
        # @param [Puppet::SSL::Host] (Puppet::SSL::Host.localhost) the SSL host to use
        #
        # @api private
        #
        def initialize(
            ssl_configuration = Puppet::SSL::Configuration.new(
                                              Puppet[:localcacert], {
                                                :ca_chain_file => Puppet[:ssl_client_ca_chain],
                                                :ca_auth_file  => Puppet[:ssl_client_ca_auth]
                                              }),
            ssl_host = Puppet::SSL::Host.localhost,
            expected_certname = nil)

          reset!
          @ssl_configuration = ssl_configuration
          @ssl_host = ssl_host
          @expected_certname = expected_certname
        end

        # Registers the instance's call method with the connection.
        #
        # @param [Net::HTTP] connection The connection to validate
        #
        # @return [void]
        #
        # @api private
        #
        def setup_connection(connection)
          super(connection)
          connection.verify_mode = OpenSSL::SSL::VERIFY_NONE
        end

        # Check's
        def certificate_name_match?
          if @expected_certname.nil?
            true
          else
            @peer_certs.last.name == @expected_certname
          end
        end

      end

    end
  end
end
